# redeliver

[![PyPI - Version](https://img.shields.io/pypi/v/redeliver.svg)](https://pypi.org/project/redeliver)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/redeliver.svg)](https://pypi.org/project/redeliver)

---

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install redeliver
```

## License

`redeliver` is distributed under the terms of the [Apache-2.0](https://spdx.org/licenses/Apache-2.0.html) license.
